@@ -1,8 +1,8 @@
 """Top-level package for populate_data_deterministic."""
 
-from .populate_data_deterministic import create_spec, create_instance, create_instances_from_definition, \
+from .populate_data_deterministic import create_spec, create_instances_from_definition, \
     create_instance_from_dump, dump_instance
 
 __author__ = """Arun Tigeraniya"""
 __email__ = 'tigeraniya@gmail.com'
-__version__ = '0.2.5'
+__version__ = '0.2.6'
