@@ -1,5 +1,6 @@
 from datetime import timedelta
 
+
 def update_user_password(instance, sp, ctx, meta=None):
     instance.set_password(sp["_password"])
     instance.save()
@@ -9,7 +10,6 @@ def update_user_password(instance, sp, ctx, meta=None):
 def update_datetime_fields(ref_field, dt_fields):
     def update_datetime_fields_inner(fields, ctx, meta=None):
         dt = fields[ref_field]
-        del fields[ref_field]
         for fld in dt_fields:
             if fld in fields and fields[fld] is not None:
                 fld_type = meta["fields"][fld]["field"].__class__.__name__
@@ -25,8 +25,8 @@ def update_datetime_fields(ref_field, dt_fields):
 def update_text_fields(ref, txt_fields):
     def update_text_fields_inner(fields, ctx, **kw):
         tref = fields[ref]
-        del fields[ref]
         for fld in txt_fields:
             fields[fld] = tref + " " + fld
         return fields
+
     return update_text_fields_inner
